# ##### BEGIN GPL LICENSE BLOCK #####
#
# This file is part of the BlenderAe Addon.
#
# BlenderAe is a Blender Addon that allows exporting of Blender data for After Effects.
# Copyright (C) 2021 Daniel Peterson
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of  MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program.  If not, see <http://www.gnu.org/licenses/>.
#
# ##### END GPL LICENSE BLOCK #####

import bpy

class VIEW3D_PT_blenderae(bpy.types.Panel):
    """Export and import selected objects to and from After Effects"""

    bl_label = "BlenderAe"
    bl_space_type = "VIEW_3D"
    bl_region_type = "UI"
    bl_category = "BlenderAe"
    bl_options = {"HEADER_LAYOUT_EXPAND"}

    @classmethod
    def poll(cls, context):
        # this panel will only show if you are in Object, Edit or Pose mode.
        return context.mode in ["OBJECT", "EDIT_MESH", "POSE"]

    def draw(self, context):

        # -------------------
        # First box
        # -------------------

        layout = self.layout
        # can have row or column. Box is used to define user interface
        box = layout.box()

        # col = layout.column(align=True)
        # custom property registered in the __init__ file
        col = box.column(align=True)
        col.prop(
            context.scene.blenderae, "ae_filepath"
        ) 

        # Set connected_text to be the stored string property
        connected_text = bpy.context.scene.blenderae.ae_connected
        ic = bpy.context.scene.blenderae.ae_ic
        custom_text = context.scene.blenderae.ae_filepath

        # Connected text and icon indicators
        row = col.row()
        row.label(text=connected_text, icon=ic)

        # Check if Ae is linked via custom properties. If not then display the connect button
        if connected_text == "----":
            row.operator("export_scene.connect_ae")

        else:
            row.operator("export_scene.disconnect_ae")

        # -------------------
        # Second box
        # -------------------

        box = layout.box()
        col = box.column(align=False)

        # Comp offset
        # col = row.column(align = True)
        row = col.row()
        # row.label(text="Center Offset")
        # row.use_property_split = True
        # row.use_property_decorate = False
        row.prop(context.scene.blenderae, "center_offset")

        # Export scale factor
        row = col.row()
        # Split the name from the value (decorate adds keyframe buttons)
        row.use_property_split = True
        row.use_property_decorate = False
        row.prop(context.scene.blenderae, "export_scale_factor")

        # Main export
        row1 = col.row()
        row1.operator("export_scene.export_ae", text="Export to Ae", icon="EXPORT")

        # Help Ae
        row2 = col.row()
        row2.operator("export_scene.help_ae", icon="HELP")

        # Import Ae Layers
        row3 = col.row()
        row3.operator("blenderae.import_ae_layers", icon="IMPORT")

        row = col.row()
        # Split the name from the value (decorate adds keyframe buttons)
        row.use_property_split = True
        row.use_property_decorate = False
        row.prop(context.scene.blenderae, "scale_factor")

        # -------------------
        # Camera sensor box
        # -------------------

        # Camera Sensor
        if (
            bpy.context.active_object is not None
            and bpy.context.active_object.type == "CAMERA"
        ):
            cam = bpy.context.active_object.data

            box = layout.box()
            col = box.column()
            col.label(text="Camera Sensor Settings")

            # Split the name from the value (decorate adds keyframe buttons)
            col.use_property_split = True
            col.use_property_decorate = True

            row = col.row()
            row.prop(cam, "sensor_fit")

            if cam.sensor_fit == "AUTO":
                col.prop(cam, "sensor_width", text="Size")
            else:
                sub = col.column(align=True)
                sub.active = cam.sensor_fit == "HORIZONTAL"
                sub.prop(cam, "sensor_width", text="Width")

                sub = col.column(align=True)
                sub.active = cam.sensor_fit == "VERTICAL"
                sub.prop(cam, "sensor_height", text="Height")

        # -------------------
        # Armature box
        # -------------------

        if (
            bpy.context.active_object is not None
            and bpy.context.active_object.type == "ARMATURE"
        ):
            box = layout.box()
            col = box.column()
            col.label(text="Armature Options")

            row = col.row()
            row.prop(context.scene.blenderae, "include_tails")