# ##### BEGIN GPL LICENSE BLOCK #####
#
# This file is part of the BlenderAe Addon.
#
# BlenderAe is a Blender Addon that allows exporting of Blender data for After Effects.
# Copyright (C) 2021 Daniel Peterson
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of  MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program.  If not, see <http://www.gnu.org/licenses/>.
#
# ##### END GPL LICENSE BLOCK #####

import bpy


class BLAE_props(bpy.types.PropertyGroup):
    """
    Grouped Properties for the scene context of BlenderAe - https://www.youtube.com/watch?v=9fuFDHR-UkE
    """

    ae_filepath: bpy.props.StringProperty(
        name="Ae Path",
        default="",
        subtype="FILE_PATH",
    )

    ae_connected: bpy.props.StringProperty(
        name="Ae Connected",
        default="----",
    )

    ae_ic: bpy.props.StringProperty(
        name="Ae Connected Icon",
        default="UNLINKED",
    )

    export_scale_factor: bpy.props.FloatProperty(
        name="Export Scale",
        description="Change the export scene scale for the exported data",
        default=1,
        min=0,
        # max=3.402823e+38,
        soft_min=0.1,
        soft_max=20,
        step=1,
        precision=2,
        # options={'ANIMATABLE'},
        # override=set(),
        # tags=set(),
        # subtype='NONE',
        # unit='NONE',
        # update=None,
        # get=None,
        # set=None
    )

    scale_factor: bpy.props.FloatProperty(
        name="Import Scale",
        description="Adjust the imported scale. Use 10.0 for roundtripping a camera between Blender and Ae.",
        default=1,
        min=0,
        # max=3.402823e+38,
        soft_min=0.01,
        soft_max=20,
        step=1,
        precision=2,
        # options={'ANIMATABLE'},
        # override=set(),
        # tags=set(),
        # subtype='NONE',
        # unit='NONE',
        # update=None,
        # get=None,
        # set=None
    )

    # https://docs.blender.org/api/current/bpy.props.html?highlight=update%20property#bpy.props.BoolProperty
    center_offset: bpy.props.BoolProperty(
        name="Use Ae Comp Center",
        description="Use the After Effects composition center values (eg. 1080p has a center of [960, 540, 0]) instead of a [0,0,0] world origin",
        default=False,
        # options = 'ANIMATABLE',
        # override = 'set()',
        # tags = 'set()',
        # subtype = 'NONE',
        # update = None,
        # get = None,
        # set = None,
    )

    include_tails: bpy.props.BoolProperty(
        name="Include Bone Tails",
        description="Include the tail position of selected bones in the exported data",
        default=False,
        # options = 'ANIMATABLE',
        # override = 'set()',
        # tags = 'set()',
        # subtype = 'NONE',
        # update = None,
        # get = None,
        # set = None,
    )
